#!/bin/sh

. /usr/share/sentinelle/utils/dbs.inc

echo "================================================"
echo "Suppression des ID Zephir obsolètes"
date
echo ""

VERBOSE=0 # Pas verbeux par défaut, n'affiche pas la progression
YES=0 # Pas de Yes mode par défaut

while getopts vf flag
do
	  case  $flag in
		  v) VERBOSE=1
		  ;;

		  f) YES=1
		  ;;
	  esac

done

# Ensemble des ID contenu dans zephir
echo -n " Récupération des ID Zephir : "
ID_ZEPHIR=" "`python /usr/share/sentinelle-server/scripts/GetAllServeurIdFromZephir.py`" "
NBID=`echo "$ID_ZEPHIR" | wc -w`
echo "$NBID trouvé"

# Vérification
if [ $NBID -eq 0 ] ; then
        echo ""
        echo " Aucun ID trouvé,  il y a sans doute un pb de récupération sur Zephir"
        exit
        echo ""
fi

if [ $NBID -gt 20 -a $YES -eq 1 ] ; then
        echo ""
        echo "Plus de 20 Id trouvés, par mesure de précaution "
        echo "La suppression automatique a été désactivé"
        echo ""
        exit
fi

# Récupération de toutes les tables
REGEXP="^AMON.*\|^HORUS.*\|^SCRIBE.*\|^ECLAIR.*"
TABLES=`$DBPersistance "SHOW TABLES" `
TOTAL=`echo $TABLES | wc -w`; I=0

BADKEYS=""
echo -n " Analyse des tables en cours : "

if [ $TOTAL -eq 0 ] ; then
	echo " Aucune table"
	exit
fi

for TABLE in $TABLES ; do

	# Affiche le pourcentage si mode verbeux
	if [ $VERBOSE -eq 1 ] ; then
		I=`expr $I + 1` ;P=`expr $I \* 100` ; P=`expr $P / $TOTAL`
		echo -n -e "$P%\b\b" ;if [ $P -ge 10 ] ; then  echo -n -e "\b" ; fi
	fi
	
	# Uniquement les modules Eole : AMON/HORUS/SCRIBE/AMONECOLE/ECLAIR
	echo $TABLE | grep -i "$REGEXP" >/dev/null
	if [ $? -ne 0 ] ; then
		continue
	fi

	# Récupère les srvkey de la table TABLE de la base DBLatest
	KEYS=`$DBLatest "SELECT srvkey FROM $TABLE"  | sed 's/$/ /g'  | tr -d '\n'`
	if [ "$KEYS" == "" ] ; then
		continue
	fi

	# Pour chaque srvkey de la table, on verifie si c'est dans la liste des ID zephir
	for KEY in $KEYS ; do
		echo "[ $ID_ZEPHIR ]" | grep " $KEY " >/dev/null 2>&1
		if [ $? -ne 0 ] ; then
			# On évite les doublons
			echo "[ $BADKEYS ]" | grep " $KEY " >/dev/null 2>&1
			if [ $? -ne 0 ] ; then
				BADKEYS="$BADKEYS $KEY"
			fi
		fi
	done

done

echo "\b 100%"
echo ""

if [ "$BADKEYS" == "" ] ; then
	echo " Aucun ID a supprimer"
	date
	exit
fi

echo  "=> Liste des clefs présentes dans Sentinelle, mais ne correspondant pas a un id Zephir"
echo "  $BADKEYS"


if [ $YES -ne 1 ] ; then
	echo ""
	echo -n "Voulez-vous les supprimer de la base Sentinelle o/n ? : "
	read REP

	if [ "$REP" != "o" ] ; then
		exit
	fi
fi

echo "" 
echo  "Suppression en cours "
for ID in $BADKEYS ; do
	echo -n " ° Id zephir $ID : "
	I=0
	for TABLE in `echo $TABLES` ; do

		if [ $VERBOSE -eq 1 ] ; then
			I=`expr $I + 1` ;P=`expr $I \* 100` ; P=`expr $P / $TOTAL`
			echo -n -e "$P%\b\b" ;if [ $P -ge 10 ] ; then  echo -n -e "\b" ; fi
		fi

		echo $TABLE | grep -i "$REGEXP" >/dev/null
		if [ $? -eq 0 ] ; then
			$DBLatest "DELETE FROM $TABLE WHERE srvkey = '$ID'"
		fi
	done
	echo "\b 100% "
done

date
